# R Script for plotting the data in "Stiffness and articulatory overlap in Moroccan Arabic consonant clusters",
# Roon, Hoole, Zeroual, Du, & Gafos
# Laboratory Phonology
# Kevin Roon, 2021

library(ggplot2)
library(Rmisc)
library(tidyr)
library(gridExtra)
library(lme4)
library(lmerTest)
library(emmeans)

data_all <- read.csv("~/Roon_etal_LabPhon2021.csv")

#Factorize the necesssary columns
data_all$Speaker <- factor(data_all$Speaker)
data_all$Stimulus <- factor(data_all$Stimulus)

data_all$C1_Articulator <- factor(ifelse(data_all$C1_Articulator == "tongue tip", "TT", ifelse(data_all$C1_Articulator == "tongue back", "TB", "LL")))
data_all$C1_Articulator <- relevel(data_all$C1_Articulator, "LL")
data_all$C1_Articulator <- relevel(data_all$C1_Articulator, "TT")
data_all$C2_Articulator <- factor(ifelse(data_all$C2_Articulator == "tongue tip", "TT", ifelse(data_all$C2_Articulator == "tongue back", "TB", "LL")))
data_all$C2_Articulator <- relevel(data_all$C2_Articulator, "TT")
data_all$C2_Articulator <- relevel(data_all$C2_Articulator, "LL")
data_all$ClusterType <- factor(paste(data_all$C1_Articulator, data_all$C2_Articulator, sep = "-"))
data_all$ClusterType <- relevel(data_all$ClusterType, "TB-LL")
data_all$ClusterType <- relevel(data_all$ClusterType, "TT-TB")
data_all$ClusterType <- relevel(data_all$ClusterType, "TT-LL")
data_all$ClusterType <- relevel(data_all$ClusterType, "LL-TB")
data_all$ClusterType <- relevel(data_all$ClusterType, "LL-TT")

data_all$Place_Order <- factor(ifelse(data_all$Place_Order == "FB", "Front-to-back", "Back-to-front"))
data_all$Place_Order <- relevel(data_all$Place_Order, "Back-to-front")
data_all$Place_Order <- relevel(data_all$Place_Order, "Front-to-back")

#Trim outliers based on more than 3 SDs from the mean
data_trim <- data_all[data_all$C1_PV_to.cm.sec. < mean(data_all$C1_PV_to.cm.sec.) + 3* sd(data_all$C1_PV_to.cm.sec.), ]
data_trim <- data_trim[data_trim$C2_PV_to.cm.sec. < mean(data_all$C2_PV_to.cm.sec.) + 3* sd(data_all$C2_PV_to.cm.sec.), ]
data_trim <- data_trim[abs(data_trim$PV_Difference) < mean(data_all$PV_Difference) + 3* sd(data_all$PV_Difference), ]
data_trim <- data_trim[data_trim$C1_Stiffness < mean(data_all$C1_Stiffness) + 3* sd(data_all$C1_Stiffness), ]
data_trim <- data_trim[data_trim$C2_Stiffness < mean(data_all$C2_Stiffness) + 3* sd(data_all$C2_Stiffness), ]
data_trim <- data_trim[abs(data_trim$Stiffness_Difference) < mean(data_all$Stiffness_Difference) + 3* sd(data_all$Stiffness_Difference), ]
data_trim <- data_trim[data_trim$Relative_Overlap < mean(data_all$Relative_Overlap) + 3* sd(data_all$Relative_Overlap), ]
data_trim <- data_trim[data_trim$Relative_Overlap > mean(data_all$Relative_Overlap) - 3* sd(data_all$Relative_Overlap), ]
data_trim <- data_trim[data_trim$Onset_Lag > mean(data_all$Onset_Lag) - 3* sd(data_all$Onset_Lag), ]

# Determine the number of tokens per speaker, by Place Order
PO_Summ_bySpeaker <- summarySE(data_trim, measurevar= "ID",groupvars=c("Place_Order", "Speaker"))

### Hypothesis H-J1: Differences by articulator (within cluster position, C1 or C2)
## First PV
pv_gathered <- gather(data_trim, ClusterPosition, PeakVelocity, C1_PV_to.cm.sec., C2_PV_to.cm.sec.)
pv_gathered$Articulator <- factor(ifelse(pv_gathered$ClusterPosition == 'C1_Stiffness', as.character(pv_gathered$C1_Articulator), as.character(pv_gathered$C2_Articulator)))
pv_gathered$Articulator <- relevel(pv_gathered$Articulator, "LL")
pv_gathered$Articulator <- relevel(pv_gathered$Articulator, "TT")
pv_gathered$ClusterPosition <- factor(substr(pv_gathered$ClusterPosition, 1, 2))

## Generate sub-figure, plotted below with stiffness
fig4a <- ggplot(pv_gathered, aes(x=ClusterPosition, y=PeakVelocity, fill=Articulator)) + 
  geom_violin(draw_quantiles = c(0.5), scale = 'width', alpha = .75, position = position_dodge(width = 0.9), show.legend = FALSE) +
  geom_jitter(position = position_jitterdodge(seed = 1, dodge.width = 0.9), show.legend = FALSE) +
  ylab("Peak Velocity (cm/sec)") + xlab("Cluster Position") + scale_x_discrete(labels=c("C1_PV_to.cm.sec." = "C1", "C2_PV_to.cm.sec." = "C2")) +
  ggtitle('A') + geom_vline(xintercept=1.5, color="white", size=1.25) +
  scale_fill_manual(values=c("green4", "firebrick2", "royalblue1")) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, face = "bold"), plot.title = element_text(size = 16, face = "bold"))

## Statistics
## (Table IV, left side)
PV_by_art_lme <- lmer(PeakVelocity ~ Articulator*ClusterPosition + (1 + Articulator|Speaker) + (1|Stimulus), pv_gathered)
anova(PV_by_art_lme)
## (Table V, left side)
PV_by_art.emm <- emmeans(PV_by_art_lme, ~ ClusterPosition * Articulator)
pairs(PV_by_art.emm)

## Then stiffness
stiffness_gathered <- gather(data_trim, ClusterPosition, Stiffness, C1_Stiffness, C2_Stiffness)
stiffness_gathered$Articulator <- factor(ifelse(stiffness_gathered$ClusterPosition == 'C1_Stiffness', as.character(stiffness_gathered$C1_Articulator), as.character(stiffness_gathered$C2_Articulator)))
stiffness_gathered$Articulator <- relevel(stiffness_gathered$Articulator, "LL")
stiffness_gathered$Articulator <- relevel(stiffness_gathered$Articulator, "TT")
stiffness_gathered$ClusterPosition <- factor(substr(stiffness_gathered$ClusterPosition, 1, 2))

fig4b <- ggplot(stiffness_gathered, aes(x=ClusterPosition, y=Stiffness, fill=Articulator)) + 
  geom_violin(draw_quantiles = c(0.5), scale = 'width', alpha = .75, position = position_dodge(width = 0.9)) +
  geom_jitter(position = position_jitterdodge(seed = 1, dodge.width = 0.9), show.legend = FALSE) +
  ylab("Measured Stiffness (k')") + xlab("Cluster Position") + scale_x_discrete(labels=c("C1_Stiffness" = "C1", "C2_Stiffness" = "C2")) +
  ggtitle('B') + geom_vline(xintercept=1.5, color="white", size=1.25) +
  scale_fill_manual(values=c("green4", "firebrick2", "royalblue1")) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, face = "bold"), plot.title = element_text(size = 16, face = "bold"))

## Statistics
## (Table IV, right side)
stiffness_by_art_lme <- lmer(Stiffness ~ Articulator*ClusterPosition + (1 + Articulator|Speaker) + (1|Stimulus), stiffness_gathered)
anova(stiffness_by_art_lme)
## (Table V, right side)
stiffness_by_art.emm.art <- emmeans(stiffness_by_art_lme, ~ ClusterPosition * Articulator)
pairs(stiffness_by_art.emm.art)

## Generate Fig. 4
# (This g_legend function is also used below for Fig. 6)
g_legend<-function(a.gplot){
  tmp <- ggplot_gtable(ggplot_build(a.gplot))
  leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
  legend <- tmp$grobs[[leg]]
  return(legend)}
fig4legend <- g_legend(fig4b)
grid.arrange(fig4a, fig4b + theme(legend.position="none"), fig4legend,ncol = 3, nrow=1, widths=c(10,10,4))

### Hypothesis H-J2: PV and Stiffness differences based on cluster type
data_trim$C1_Articulator <- factor(data_trim$C1_Articulator)
data_trim$C2_Articulator <- factor(data_trim$C2_Articulator)

## Fig. 5
# re-level the cluster types based on prediction of H-J2
data_trim$ClusterType <- relevel(data_trim$ClusterType, "TB-TT")
data_trim$ClusterType <- relevel(data_trim$ClusterType, "TB-LL")
data_trim$ClusterType <- relevel(data_trim$ClusterType, "LL-TT")
data_trim$ClusterType <- relevel(data_trim$ClusterType, "LL-TB")
data_trim$ClusterType <- relevel(data_trim$ClusterType, "TT-LL")
data_trim$ClusterType <- relevel(data_trim$ClusterType, "TT-TB")
fig5a <- ggplot(data_trim, aes(x=ClusterType, y=Relative_Overlap, fill=C2_Articulator)) + ylab("Relative Overlap") + 
  geom_violin(draw_quantiles = c(0.5), scale = 'width') + ggtitle('A') +
  theme(legend.position = "none" , legend.title = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(), axis.text.y = element_text(size = 16, face = "bold"), axis.title.y = element_text(size = 16, face = "bold"), plot.title = element_text(size = 16, face = "bold")) +
  annotate("rect", xmin=0.4, xmax=2.5, ymin=-Inf, ymax=Inf, alpha=.75, fill="green4") +
  annotate("rect", xmin=2.5, xmax=4.5, ymin=-Inf, ymax=Inf, alpha=.6, fill="firebrick2") +
  annotate("rect", xmin=4.5, xmax=Inf, ymin=-Inf, ymax=Inf, alpha=.75, fill="royalblue1") +
  geom_violin(draw_quantiles = c(0.5), scale = 'width', alpha = .75) + geom_jitter(width = .1) +
  geom_vline(xintercept=2.5, color="white", size=.75) + geom_vline(xintercept=4.5, color="white", size=.75) +
  geom_hline(yintercept=0, color="gray", size=.75)

fig5b <- ggplot(data_trim, aes(x=ClusterType, y=Onset_Lag, fill=C2_Articulator)) + 
  ylab("Onset Lag (ms)") + xlab("Cluster Type") +
  geom_violin(draw_quantiles = c(0.5), scale = 'width') + ggtitle('B') +
  theme(legend.position = "none" , legend.title = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(angle=90, size = 16, face = "bold"), axis.text.y = element_text(size = 16, face = "bold"), axis.title.y = element_text(size = 16, face = "bold"), axis.title.x = element_text(size = 16, face = "bold"), plot.title = element_text(size = 16, face = "bold")) +
  annotate("rect", xmin=0.4, xmax=2.5, ymin=-Inf, ymax=Inf, alpha=.75, fill="green4") +
  annotate("rect", xmin=2.5, xmax=4.5, ymin=-Inf, ymax=Inf, alpha=.6, fill="firebrick2") +
  annotate("rect", xmin=4.5, xmax=Inf, ymin=-Inf, ymax=Inf, alpha=.75, fill="royalblue1") +
  geom_violin(draw_quantiles = c(0.5), scale = 'width', alpha = .75) + geom_jitter(width = .1) +
  geom_vline(xintercept=2.5, color="white", size=.75) + geom_vline(xintercept=4.5, color="white", size=.75) +
  geom_hline(yintercept=0, color="gray", size=.75)

grid.arrange(fig5a, fig5b)

#Statistics (Table VI)
CTH_RelOverlap <- lmer(Relative_Overlap ~ ClusterType + (1|Speaker) + (1|Stimulus), data_trim)
anova(CTH_RelOverlap)
summary(CTH_RelOverlap)

CTH_OnsetLag <- lmer(Onset_Lag ~ ClusterType + (1|Speaker) + (1|Stimulus), data_trim)
anova(CTH_OnsetLag)
summary(CTH_OnsetLag)

### Hypothesis H-3: Overlap as a function of PV Difference or Stiffness Difference
## Fig. 6
fig6a <- ggplot(data_trim, aes(y=Relative_Overlap, x=PV_Difference, color=ClusterType)) + ggtitle('A') +
  ylab("Relative Overlap") + xlab("PV Difference (cm/s,H-3 PV)") +
  geom_point(aes(color= ClusterType), size = .75, alpha = .8) +
  geom_smooth(method = "lm", se = TRUE, size = 1, alpha = .25) +
  geom_smooth(method = 'lm', size = 1, colour = 'black', se = F) +
  theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.y = element_text(size = 14), axis.title.x = element_text(size = 14), plot.title = element_text(size = 16, face = "bold")) +
  geom_vline(xintercept=0, color="white", size=.75)

fig6b <- ggplot(data_trim, aes(y=Onset_Lag, x=PV_Difference, color=ClusterType)) + ggtitle('B') +
  ylab("Onset Lag (ms)") + xlab("PV Difference (cm/s, H-3 PV)") +
  geom_point(aes(color= ClusterType), size = .5, alpha = .8) +
  geom_smooth(method = "lm", se = TRUE, size = 1, alpha = .25) +
  geom_smooth(method = 'lm', size = 1, colour = 'black', se = F) +
  theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.y = element_text(size = 14), axis.title.x = element_text(size = 14), plot.title = element_text(size = 16, face = "bold")) +
  geom_vline(xintercept=0, color="white", size=.75)

fig6c <- ggplot(data_trim, aes(y=Relative_Overlap, x=Stiffness_Difference, color=ClusterType)) + ggtitle('C') +
  ylab("Relative Overlap") + xlab("Stiffness Difference (H-3 Stiffness)") +
  geom_point(aes(color= ClusterType), size = .5, alpha = .8) +
  geom_smooth(method = "lm", se = TRUE, size = 1, alpha = .25) +
  geom_smooth(method = 'lm', size = 1, colour = 'black', se = F) +
  theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.y = element_text(size = 14), axis.title.x = element_text(size = 14), plot.title = element_text(size = 16, face = "bold")) +
  geom_vline(xintercept=0, color="white", size=.75)

fig6d <- ggplot(data_trim, aes(y=Onset_Lag, x=Stiffness_Difference, color=ClusterType)) + ggtitle('D') +
  ylab("Onset Lag (ms)") + xlab("Stiffness Difference (H-3 Stiffness)") +
  geom_point(aes(color= ClusterType), size = .5, alpha = .8) +
  geom_smooth(method = "lm", se = TRUE, size = 1, alpha = .25) +
  geom_smooth(method = 'lm', size = 1, colour = 'black', se = F) +
  theme(legend.position = "bottom", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(size = 14), axis.text.y = element_text(size = 14), axis.title.y = element_text(size = 14), axis.title.x = element_text(size = 14), plot.title = element_text(size = 16, face = "bold"), legend.text = element_text(size=16, face = "bold"), legend.title = element_text(size=16, face = "bold")) +
  geom_vline(xintercept=0, color="white", size=.75)

fig6legend <- g_legend(fig6d)

grid.arrange(arrangeGrob(fig6a, fig6b, fig6c, fig6d + theme(legend.position="none"),
                         ncol = 2, nrow=2), fig6legend, nrow=2, heights=c(10, 1))
#Statistics (Table VII)
# A
PVDH_RelOverlap <- lmer(Relative_Overlap ~ PV_Difference + Place_Order+ (1 + Place_Order|Speaker) + (1 | Stimulus), data_trim)
anova(PVDH_RelOverlap)
summary(PVDH_RelOverlap)
# B
PVDH_OnsetLag <- lmer(Onset_Lag ~ PV_Difference + Place_Order + (1 + Place_Order|Speaker) + (1|Stimulus), data_trim)
anova(PVDH_OnsetLag)
summary(PVDH_OnsetLag)
# C
SDH_RelOverlap <- lmer(Relative_Overlap ~ Stiffness_Difference + Place_Order + (1 + Place_Order|Speaker) + (1|Stimulus), REML = TRUE, data_trim)
anova(SDH_RelOverlap)
summary(SDH_RelOverlap)
# D
SDH_OnsetLag <- lmer(Onset_Lag ~ Stiffness_Difference + Place_Order + (1 + Place_Order|Speaker) + (1|Stimulus), data_trim)
anova(SDH_OnsetLag)
summary(SDH_OnsetLag)
